<?php

/*
  Plugin Name: Tickera Custom Forms Date Picker Element
  Plugin URI: http://tickera.com/
  Description: Adds date picker element to the custom forms
  Author: Tickera.com
  Author URI: http://tickera.com/
  Version: 1.1

  Copyright 2017 Tickera (http://tickera.com/)
 */

add_action('tc_load_additional_elements', 'tc_custom_form_date_picker_field');

add_action('wp_enqueue_scripts', 'tc_custom_form_date_picker_field_front_header');
add_action('admin_enqueue_scripts', 'tc_custom_form_date_picker_field_admin_scripts');

function tc_custom_form_date_picker_field_admin_scripts() {
    wp_enqueue_style('addon-style', plugins_url('includes/css/style.css', __FILE__));
}

function strip_array_indices($ArrayToStrip) {
    foreach ($ArrayToStrip as $objArrayItem) {
        $NewArray[] = $objArrayItem;
    }

    return( $NewArray );
}

function tc_custom_form_date_picker_field_front_header() {
    global $wp_locale;

    wp_enqueue_script('jquery-ui-datepicker');
    wp_enqueue_style('jquery-style', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/themes/smoothness/jquery-ui.css');

    wp_register_script('tc-custom-form-date-picker-main', plugins_url('includes/js/main.js', __FILE__), '', '', true);
    wp_enqueue_script('tc-custom-form-date-picker-main');

    $aryArgs = array(
        'closeText' => __('Done', 'tc'),
        'currentText' => __('Today', 'tc'),
        'monthNames' => strip_array_indices($wp_locale->month),
        'monthNamesShort' => strip_array_indices($wp_locale->month_abbrev),
        'monthStatus' => __('Show a different month', 'tc'),
        'dayNames' => strip_array_indices($wp_locale->weekday),
        'dayNamesShort' => strip_array_indices($wp_locale->weekday_abbrev),
        'dayNamesMin' => strip_array_indices($wp_locale->weekday_initial),
        'dateFormat' => dateStringToDatepickerFormat("d/m/yy"),
        'firstDay' => get_option('start_of_week'),
    );

    wp_localize_script('tc-custom-form-date-picker-main', 'objectL10n', $aryArgs);
}

function dateStringToDatepickerFormat($dateString) {
    $pattern = array(
        //day
        'd', //day of the month
        'j', //3 letter name of the day
        'l', //full name of the day
        'z', //day of the year
        //month
        'F', //Month name full
        'M', //Month name short
        'n', //numeric month no leading zeros
        'm', //numeric month leading zeros
        //year
        'Y', //full numeric year
        'y'  //numeric year: 2 digit
    );
    $replace = array(
        'dd', 'd', 'DD', 'o',
        'MM', 'M', 'm', 'mm',
        'yy', 'y'
    );
    foreach ($pattern as &$p) {
        $p = '/' . $p . '/';
    }
    return preg_replace($pattern, $replace, $dateString);
}

function tc_custom_form_date_picker_field() {

    class tc_input_date_picker_field_form_element extends TC_Form_Elements {

        var $element_name = 'tc_input_date_picker_field_form_element';
        var $element_title = 'Date Picker';
        var $element_type = 'text';
        var $element_html_class_name = 'tc_custom_date_picker_element';

        function on_creation() {
            global $wp_query;

            $this->element_title = apply_filters('tc_input_date_field_form_element_title', __('Date Picker', 'tc'));
            $this->field_name = isset($this->id) ? get_post_meta($this->id, 'name', true) : '';

            $post = get_post($this->id);
            $title = isset($post->post_title) ? $post->post_title : '';

            $this->field_label = isset($this->id) ? $title : '';
        }

        function date_format_php_to_js($sFormat) {
            switch ($sFormat) {
                //Predefined WP date formats
                case 'F j, Y':
                    return( 'MM dd, yy' );
                    break;
                case 'Y/m/d':
                    return( 'yy/mm/dd' );
                    break;
                case 'm/d/Y':
                    return( 'mm/dd/yy' );
                    break;
                case 'd/m/Y':
                    return( 'dd/mm/yy' );
                    break;
            }
        }

        function save($form_id) {
            $element_data = $_POST[$this->element_name];
            $elements_count = (count($element_data['field_name']) - 1);

            for ($i = 0; $i <= $elements_count; $i++) {
                if ((isset($element_data['field_label'][$i]) && !empty($element_data['field_label'][$i])) || (isset($element_data['field_name'][$i]) && !empty($element_data['field_name'][$i]))) {
                    $post_data = array(
                        'post_status' => 'publish',
                        'post_parent' => $form_id,
                        'post_title' => isset($element_data['field_label'][$i]) ? $element_data['field_label'][$i] : '',
                        'post_name' => isset($element_data['field_name'][$i]) ? $element_data['field_name'][$i] : sanitize_key($element_data['field_label'][$i]),
                        'post_content' => isset($element_data['field_values'][$i]) ? $element_data['field_values'][$i] : '',
                        'post_type' => $this->post_type
                    );

                    if (isset($element_data['field_post_id'][$i]) && is_numeric($element_data['field_post_id'][$i])) {
                        $post_data['ID'] = $element_data['field_post_id'][$i];
                    }

                    $post_id = wp_insert_post($post_data);

                    $post_metas = array(
                        'placeholder' => isset($element_data['field_placeholder'][$i]) ? $element_data['field_placeholder'][$i] : '',
                        'description' => isset($element_data['field_description'][$i]) ? $element_data['field_description'][$i] : '',
                        'default_value' => isset($element_data['field_default_values'][$i]) ? $element_data['field_default_values'][$i] : '',
                        'required' => isset($element_data['field_required'][$i]) ? $element_data['field_required'][$i] : '',
                        'export' => isset($element_data['field_export'][$i]) ? $element_data['field_export'][$i] : '',
                        'show_in_checkin_app' => isset($element_data['field_show_in_checkin_app'][$i]) ? $element_data['field_show_in_checkin_app'][$i] : '',
                        'as_ticket_template' => isset($element_data['field_as_ticket_template'][$i]) ? $element_data['field_as_ticket_template'][$i] : '',
                        'order_details' => isset($element_data['field_order_details'][$i]) ? $element_data['field_order_details'][$i] : '',
                        'order_column' => isset($element_data['field_order_column'][$i]) ? $element_data['field_order_column'][$i] : '',
                        'order' => isset($element_data['field_order'][$i]) ? $element_data['field_order'][$i] : '',
                        'row' => isset($element_data['field_row'][$i]) ? $element_data['field_row'][$i] : '',
                        'field_type' => $this->element_name,
                    );

                    //Make sure that we set field name only once so we don't loose data upon changing field label
                    $name = get_post_meta($post_id, 'name', true);

                    if (!isset($name) || (isset($name) && empty($name))) {
                        $post_metas['name'] = sanitize_key(isset($element_data['field_label'][$i]) ? str_replace('-', '_', $element_data['field_label'][$i]) . '_tcfn_' . rand(1, 9999) : 'tc_field_name_' . rand(1, 9999) );
                    }

                    foreach ($post_metas as $meta_key => $meta_value) {
                        update_post_meta($post_id, $meta_key, $meta_value);
                    }
                }
            }
        }

        function admin_order_details_page_value() {
            $value = array(
                'id' => $this->standard_field_name($this->element_name, true),
                'field_name' => 'tc_cart_info',
                'field_title' => $this->standard_field_label($this->element_name, true),
                'field_type' => 'function',
                'function' => 'tc_get_input_admin_order_details_page_value',
                'field_description' => '',
                'table_visibility' => false,
                'post_field_type' => 'post_meta'
            );

            return isset($value) && !empty($value) ? $value : '-';
        }

        function admin_content() {
            $this->standard_fields($this->element_name);
            $this->common_fields($this->element_name);
        }

    }

    tc_register_form_element('tc_input_date_picker_field_form_element', __('Date Picker', 'tc'));
}

?>